aeron_async_remove_publication

Function aeron_async_remove_publication 

pub unsafe extern "C" fn aeron_async_remove_publication(
    registration_id: i64,
    client: *mut aeron_t,
    on_complete: aeron_notification_t,
    on_complete_clientd: *mut c_void,
) -> c_int
Asynchronously remove a publication. If there is an aeron_publication_t object for that publication, it will get closed and freed.

@param registration_id of the publication to be removed. @param client which owns the publication. @param on_complete optional callback to execute once the publication has been removed. This may happen on a separate thread, so the caller should ensure that clientd has the appropriate lifetime. Use NULL if not needed. @param on_complete_clientd parameter to pass to the on_complete callback. @return 0 for success or -1 for error.