aeron_image_release

Function aeron_image_release 

pub unsafe extern "C" fn aeron_image_release(
    image: *mut aeron_image_t,
) -> c_int
Release an image that was retained by aeron_subscription_image_by_session_id or aeron_subscription_image_at_index.

Unlike aeron_subscription_image_release, this function unconditionally decrements the reference count and is safe to call after the image has become unavailable (i.e. after it has been removed from the subscription’s image list).

@param image to release @return 0 for success and -1 for error.