pub type aeron_counter_constants_t = aeron_counter_constants_stct;Expand description
Configuration for a counter that does not change during its lifetime.
Aliased Type
#[repr(C)]pub struct aeron_counter_constants_t {
pub correlation_id: i64,
pub registration_id: i64,
pub counter_id: i32,
}Fields
correlation_id: i64Return the correlation id of the counter creation request that was sent to the media driver. Correlation id is unique across all requests sent to the media driver.
registration_id: i64Return the registration id used to register this counter with the media driver.
For non-static counters this value is the same as correlation_idregistration_id parameter into
aeron_async_add_static_counter call.
counter_id: i32Identity for the counter within the counters reader and counters manager.